import type { AdaptiveCard } from 'adaptivecards';
/**
 * Creates a mod effect for Adaptive Card.
 *
 * When this hook is executed, it will return two functions for applying and undo the mod.
 * It will also monitor the DOM tree and undo-then-reapply if mutation occurred.
 *
 * The first function must be called right after DOM is mounted. The second function must be called right before re-render.
 *
 * @return {[function, function]} Two functions, the first one to apply the mod, the second one to undo the mod.
 */
export default function useAdaptiveCardModEffect<TArgs extends unknown[]>(modder: (adaptiveCard: AdaptiveCard, cardElement: HTMLElement, ...args: TArgs) => () => void, adaptiveCard: AdaptiveCard): readonly [(cardElement: HTMLElement, ...args: TArgs) => void, () => void];
//# sourceMappingURL=useAdaptiveCardModEffect.d.ts.map